@@ -12,7 +12,7 @@
 // ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 // OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-use crate::{der, Error};
+use crate::{der, equal, Error};
 use ring::signature;
 
 /// X.509 certificates and related items that are signed are almost always
@@ -48,6 +48,7 @@ pub struct SignedData<'a> {
 ///     signatureAlgorithm AlgorithmIdentifier,
 ///     signatureValue BIT STRING
 /// }
+/// ```
 ///
 /// OCSP responses (RFC 6960) look like this:
 /// ```ASN.1
@@ -312,7 +313,7 @@ struct AlgorithmIdentifier {
 
 impl AlgorithmIdentifier {
     fn matches_algorithm_id_value(&self, encoded: untrusted::Input) -> bool {
-        encoded == self.asn1_id_value
+        equal(encoded, self.asn1_id_value)
     }
 }
 
@@ -460,10 +461,12 @@ mod tests {
         let tsd = parse_test_signed_data(file_contents);
         let signature = untrusted::Input::from(&tsd.signature);
         assert_eq!(
-            Err(expected_error),
-            signature.read_all(Error::BadDer, |input| {
-                der::bit_string_with_no_unused_bits(input)
-            })
+            expected_error,
+            signature
+                .read_all(Error::BadDer, |input| {
+                    der::bit_string_with_no_unused_bits(input)
+                })
+                .unwrap_err()
         );
     }
 
@@ -481,10 +484,11 @@ mod tests {
         let tsd = parse_test_signed_data(file_contents);
         let spki = untrusted::Input::from(&tsd.spki);
         assert_eq!(
-            Err(expected_error),
+            expected_error,
             spki.read_all(Error::BadDer, |input| {
                 der::expect_tag_and_get_value(input, der::Tag::Sequence)
             })
+            .unwrap_err()
         );
     }
 
@@ -755,7 +759,7 @@ mod tests {
             if line == end_section {
                 break;
             }
-            base64.push_str(&line);
+            base64.push_str(line);
         }
 
         base64::decode(&base64).unwrap()
